@@ -138,12 +138,14 @@ const std::string DOM::get (const std::string& name)
       return /*_cache[name] =*/ "Solaris";
 #elif defined (CYGWIN)
       return /*_cache[name] =*/ "Cygwin";
-#elif defined (OPENBSD)
-      return /*_cache[name] =*/ "OpenBSD";
 #elif defined (HAIKU)
       return /*_cache[name] =*/ "Haiku";
+#elif defined (OPENBSD)
+      return /*_cache[name] =*/ "OpenBSD";
 #elif defined (FREEBSD)
       return /*_cache[name] =*/ "FreeBSD";
+#elif defined (NETBSD)
+      return /*_cache[name] =*/ "NetBSD";
 #elif defined (LINUX)
       return /*_cache[name] =*/ "Linux";
 #else
@@ -161,7 +163,7 @@ const std::string DOM::get (const std::string& name)
 ////////////////////////////////////////////////////////////////////////////////
 // DOM Supported References:
 //
-//   TODO <id>.{entry,start,end,due,until,wait}
+//   TODO <id>.{entry,start,end,scheduled,due,until,wait}
 //   TODO <id>.description
 //   TODO <id>.project
 //   TODO <id>.priority
@@ -172,7 +174,7 @@ const std::string DOM::get (const std::string& name)
 //   TODO <id>.recur
 //   TODO <id>.depends
 //
-//   TODO <uuid>.{entry,start,end,due,until,wait}
+//   TODO <uuid>.{entry,start,end,scheduled,due,until,wait}
 //   TODO <uuid>.description
 //   TODO <uuid>.project
 //   TODO <uuid>.priority
@@ -183,7 +185,7 @@ const std::string DOM::get (const std::string& name)
 //   TODO <uuid>.recur
 //   TODO <uuid>.depends
 //
-//   {entry,start,end,due,until,wait}
+//   {entry,start,end,scheduled,due,until,wait}
 //   description
 //   project
 //   priority
