@@ -34,6 +34,9 @@
 #include <string>
 #include <stdio.h>
 
+
+void initializeUrgencyCoefficients ();
+
 class Task : public std::map <std::string, std::string>
 {
 public:
@@ -56,6 +59,9 @@ public:
   float urgency_value;
   bool recalc_urgency;
 
+  bool is_blocked;
+  bool is_blocking;
+
   // Series of helper functions.
   static status textToStatus (const std::string&);
   static std::string statusToText (status);
@@ -67,10 +73,10 @@ public:
   bool has (const std::string&) const;
   std::vector <std::string> all ();
   const std::string get (const std::string&) const;
+  const std::string& get_ref (const std::string&) const;
   int get_int (const std::string&) const;
   unsigned long get_ulong (const std::string&) const;
   time_t get_date (const std::string&) const;
-  time_t get_duration (const std::string&) const;
   void set (const std::string&, const std::string&);
   void set (const std::string&, int);
   void remove (const std::string&);
@@ -97,9 +103,12 @@ public:
   void getDependencies (std::vector <int>&) const;
   void getDependencies (std::vector <std::string>&) const;
 
+  void getUDAs (std::vector <std::string>&) const;
+  void getUDAOrphans (std::vector <std::string>&) const;
+
   void substitute (const std::string&, const std::string&, bool);
 
-  void validate ();
+  void validate (bool applyDefault = true);
 
   float urgency_c () const;
   float urgency ();
@@ -107,10 +116,12 @@ public:
 private:
   int determineVersion (const std::string&);
   void legacyParse (const std::string&);
+  void validate_before (const std::string&, const std::string&);
 
   inline float urgency_priority () const;
   inline float urgency_project () const;
   inline float urgency_active () const;
+  inline float urgency_scheduled () const;
   inline float urgency_waiting () const;
   inline float urgency_blocked () const;
   inline float urgency_annotations () const;
