@@ -85,6 +85,7 @@
 //#include <CmdSynch.h>
 #include <CmdTags.h>
 #include <CmdTimesheet.h>
+#include <CmdUDAs.h>
 #include <CmdUndo.h>
 #include <CmdUrgency.h>
 #include <CmdVersion.h>
@@ -114,6 +115,8 @@ void Command::factory (std::map <std::string, Command*>& all)
   c = new CmdCompletionCommands (); all[c->keyword ()] = c;
   c = new CmdCompletionConfig ();   all[c->keyword ()] = c;
   c = new CmdCompletionIds ();      all[c->keyword ()] = c;
+  c = new CmdCompletionUDAs ();     all[c->keyword ()] = c;
+  c = new CmdCompletionUuids ();    all[c->keyword ()] = c;
   c = new CmdCompletionProjects (); all[c->keyword ()] = c;
   c = new CmdCompletionTags ();     all[c->keyword ()] = c;
   c = new CmdCompletionVersion ();  all[c->keyword ()] = c;
@@ -156,12 +159,14 @@ void Command::factory (std::map <std::string, Command*>& all)
 //  c = new CmdSynch ();              all[c->keyword ()] = c;
   c = new CmdTags ();               all[c->keyword ()] = c;
   c = new CmdTimesheet ();          all[c->keyword ()] = c;
+  c = new CmdUDAs ();               all[c->keyword ()] = c;
   c = new CmdUndo ();               all[c->keyword ()] = c;
   c = new CmdUrgency ();            all[c->keyword ()] = c;
   c = new CmdUUIDs ();              all[c->keyword ()] = c;
   c = new CmdVersion ();            all[c->keyword ()] = c;
   c = new CmdZshCommands ();        all[c->keyword ()] = c;
   c = new CmdZshCompletionIds ();   all[c->keyword ()] = c;
+  c = new CmdZshCompletionUuids (); all[c->keyword ()] = c;
 
   // Instantiate a command object for each custom report.
   std::vector <std::string> variables;
@@ -338,8 +343,6 @@ void Command::filter (std::vector <Task>& output)
         if (e.evalFilter (*task))
           output.push_back (*task);
     }
-    else
-      context.debug ("Command::filter skipping completed.data");
   }
   else
   {
@@ -372,7 +375,37 @@ bool Command::filter_shortcut (const A3& filter)
       filter[0]._raw                  == "status"          &&
       filter[1]._raw.find ("pending") != std::string::npos &&
       filter[2]._raw                  == "=")
+  {
+    context.debug ("Command::filter skipping completed.data (status:pending only)");
     return true;
+  }
+
+  // Shortcut: If the filter contains no 'or' or 'xor' operators, IDs and no UUIDs.
+  int countId   = 0;
+  int countUUID = 0;
+  int countOr   = 0;
+  int countXor  = 0;
+  std::vector <Arg>::const_iterator i;
+  for (i = filter.begin (); i != filter.end (); ++i)
+  {
+    if (i->_category == Arg::cat_op)
+    {
+      if (i->_raw == "or")  ++countOr;
+      if (i->_raw == "xor") ++countXor;
+
+    }
+    else if (i->_category == Arg::cat_id)   ++countId;
+    else if (i->_category == Arg::cat_uuid) ++countUUID;
+  }
+
+  if (countOr   == 0 &&
+      countXor  == 0 &&
+      countUUID == 0 &&
+      countId    > 0)
+  {
+    context.debug ("Command::filter skipping completed.data (IDs, no OR, no XOR, no UUID)");
+    return true;
+  }
 
   return false;
 }
@@ -450,10 +483,10 @@ void Command::modify_task (
         }
         else
         {
-          // Dependencies must be resolved to UUIDs.
+          // Dependencies are used as IDs.
           if (name == "depends")
           {
-            // Convert ID to UUID.
+            // Parse IDs
             std::vector <std::string> deps;
             split (deps, value, ',');
 
@@ -461,11 +494,31 @@ void Command::modify_task (
             std::vector <std::string>::iterator i;
             for (i = deps.begin (); i != deps.end (); i++)
             {
-              int id = strtol (i->c_str (), NULL, 10);
-              if (id < 0)
-                task.removeDependency (-id);
+              bool removal = false;
+              std::string& dep = *i;
+
+              if (dep[0] == '-')
+              {
+                removal = true;
+                dep = i->substr(1, std::string::npos);
+              }
+
+              std::vector <int> ids;
+              // Crude UUID check
+              if (dep.length () == 36)
+              {
+                int id = context.tdb2.pending.id (dep);
+                ids.push_back (id);
+              }
               else
-                task.addDependency (id);
+                A3::extract_id (dep, ids);
+
+              std::vector <int>::iterator id;
+              for (id = ids.begin (); id != ids.end(); id++)
+                if (removal)
+                  task.removeDependency (*id);
+                else
+                  task.addDependency (*id);
             }
           }
 
@@ -492,10 +545,9 @@ void Command::modify_task (
             long l = (long) strtod (result.c_str (), NULL);
             if (labs (l) < 5 * 365 * 86400)
             {
-              Duration dur (result);
+              Duration dur (value);
               Date now;
               now += l;
-              //now += dur;
               task.set (name, now.toEpochString ());
             }
             else
@@ -506,9 +558,10 @@ void Command::modify_task (
           }
 
           // Durations too.
-          else if (column->type () == "duration")
+          else if (name == "recur" ||
+                   column->type () == "duration")
           {
-            // All values must be eval'd first.
+            // All values must be eval'd first, in this case, just to catch errors.
             A3 value_tokens;
             value_tokens.capture (value);
             value_tokens = value_tokens.postfix (value_tokens.tokenize (value_tokens));
@@ -517,8 +570,11 @@ void Command::modify_task (
             std::string result = e.evalExpression (task);
             context.debug (std::string ("Eval '") + value + "' --> '" + result + "'");
 
-            Duration d (result);
-            task.set (name, result);
+            Duration d (value);
+
+            // Deliberately storing the 'raw' value, which is necessary for
+            // durations like 'weekday'..
+            task.set (name, name == "recur" ? value : result);
           }
 
           // Need handling for numeric types, used by UDAs.
@@ -543,7 +599,12 @@ void Command::modify_task (
 
           // By default, just add/remove it.
           else
-            task.set (name, value);
+          {
+            if (column->validate (value))
+              task.set (name, value);
+            else
+              throw format (STRING_INVALID_MOD, name, value);
+          }
 
           // Warn about deprecated/obsolete attribute usage.
           legacyAttributeCheck (name);
@@ -679,19 +740,7 @@ bool Command::next_mod_group (const A3& input, Arg& arg, unsigned int& pos)
   {
     arg = input[pos++];
 
-    // Date attributes aggregate durations and operators.
-    if (arg._type == Arg::type_date &&
-        arg._category == Arg::cat_attr)
-    {
-      while (pos < input.size () &&
-             (input[pos]._type     == Arg::type_duration ||
-              input[pos]._category == Arg::cat_op))
-      {
-        arg._raw += " " + input[pos++]._raw;
-      }
-    }
-
-    else if (arg._raw == "depends")
+    if (arg._raw == "depends")
     {
       while (pos < input.size () &&
              (input[pos]._category == Arg::cat_op ||
