@@ -56,6 +56,7 @@ extern Context context;
 void handleRecurrence ()
 {
   std::vector <Task> tasks = context.tdb2.pending.get_tasks ();
+  Date now;
 
   // Look at all tasks and find any recurring ones.
   std::vector <Task>::iterator t;
@@ -68,12 +69,10 @@ void handleRecurrence ()
       std::vector <Date> due;
       if (!generateDueDates (*t, due))
       {
-        std::cout << format (STRING_RECUR_PAST_UNTIL, trim (t->get ("description")))
-                  << "\n";
-
         // Determine the end date.
         t->setStatus (Task::deleted);
         context.tdb2.modify (*t);
+        context.footnote (onExpiration (*t));
         continue;
       }
 
@@ -137,6 +136,18 @@ void handleRecurrence ()
         context.tdb2.modify (*t);
       }
     }
+
+    // Non-recurring tasks expire too.
+    else
+    {
+      if (t->has ("until") &&
+          Date (t->get_date ("until")) < now)
+      {
+        t->setStatus (Task::deleted);
+        context.tdb2.modify(*t);
+        context.footnote (onExpiration (*t));
+      }
+    }
   }
 }
 
@@ -386,7 +397,7 @@ int getDueState (const std::string& due)
     Date dt (::atoi (due.c_str ()));
 
     // rightNow is the current date + time.
-    Date rightNow;
+    static Date rightNow;
     Date thisDay (rightNow.month (), rightNow.day (), rightNow.year ());
 
     if (dt < rightNow)
@@ -408,6 +419,36 @@ int getDueState (const std::string& due)
   return 0;
 }
 
+////////////////////////////////////////////////////////////////////////////////
+// Determines whether a task is overdue.  Returns
+//   0 = not due at all
+//   1 = imminent
+//   2 = today
+//   3 = overdue
+int getDueState (const Date& due)
+{
+  // rightNow is the current date + time.
+  static Date rightNow;
+  Date thisDay (rightNow.month (), rightNow.day (), rightNow.year ());
+
+  if (due < rightNow)
+    return 3;
+
+  if (rightNow.sameDay (due))
+    return 2;
+
+  int imminentperiod = context.config.getInteger ("due");
+
+  if (imminentperiod == 0)
+    return 1;
+
+  Date imminentDay = thisDay + imminentperiod * 86400;
+  if (due < imminentDay)
+    return 1;
+
+  return 0;
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 // Returns a Boolean indicator as to whether a nag message was generated, so
 // that commands can control the number of nag messages displayed (ie one is
@@ -464,12 +505,12 @@ bool nag (Task& task)
     }
 
     // General form is "if there are no more deserving tasks", suppress the nag.
-    if (isOverdue                                                 ) return false;
-    if (pri == 'H' && !overdue                                    ) return false;
-    if (pri == 'M' && !overdue && !high                           ) return false;
-    if (pri == 'L' && !overdue && !high && !medium                ) return false;
-    if (pri == ' ' && !overdue && !high && !medium && !low        ) return false;
-    if (dependencyIsBlocking (task) && !dependencyIsBlocked (task)) return false;
+    if (isOverdue                                          ) return false;
+    if (pri == 'H' && !overdue                             ) return false;
+    if (pri == 'M' && !overdue && !high                    ) return false;
+    if (pri == 'L' && !overdue && !high && !medium         ) return false;
+    if (pri == ' ' && !overdue && !high && !medium && !low ) return false;
+    if (task.is_blocking && !task.is_blocked               ) return false;
 
     // All the excuses are made, all that remains is to nag the user.
     context.footnote (nagMessage);
